/* ByteOrder.java -- 
   Copyright (C) 2002, 2004  Free Software Foundation, Inc.

This file is part of GNU Classpath.

GNU Classpath is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

GNU Classpath is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU Classpath; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version. */


package java.nio;

/**
 * @author Michael Koch (konqueror@gmx.de)
 * @since 1.4
 */
public final class ByteOrder
{
  /**
   * Constant indicating big endian byte order.
   */
  public static final ByteOrder BIG_ENDIAN = new ByteOrder();

  /**
   * Constant indicating little endian byte order.
   */
  public static final ByteOrder LITTLE_ENDIAN = new ByteOrder();

  /**
   * Returns the native byte order of the platform currently running.
   *
   * @return the native byte order
   */
  public static ByteOrder nativeOrder()
  {
    // Let this fail with an NPE when the property is not set correctly.
    // Otherwise we risk that NIO is silently working wrong.
    return (System.getProperty("gnu.cpu.endian").equals("big")
            ? BIG_ENDIAN : LITTLE_ENDIAN);
  }

  /**
   * Returns a string representation of the byte order.
   *
   * @return the string
   */
  public String toString()
  {
    return this == BIG_ENDIAN ? "BIG_ENDIAN" : "LITTLE_ENDIAN";
  }

  // This class can only be instantiated here.
  private ByteOrder()
  {
  }
}
